@@ -3,6 +3,6 @@ pub mod native;
 pub trait Transpose
 {
     type Output;
-    fn transpose(self: Self) -> Self::Output;
+    fn transpose(self) -> Self::Output;
 }
 
