@@ -23,7 +23,7 @@ impl<T> Sub<Vector<T>> for Vector<T>
     ///
     /// assert_eq!(res_ref, a - b)
     /// ```
-    fn sub(self: Self, rhs: Vector<T>) -> Self::Output
+    fn sub(self, rhs: Vector<T>) -> Self::Output
     {
         &self - &rhs
     }
@@ -47,7 +47,7 @@ impl<'a, 'b, T> Sub<&'b Vector<T>> for &'a Vector<T>
     ///
     /// assert_eq!(res_ref, &a - &b)
     /// ```
-    fn sub(self: Self, rhs: &'b Vector<T>) -> Self::Output
+    fn sub(self, rhs: &'b Vector<T>) -> Self::Output
     {
         Vector { data: (&self.data).sub(&rhs.data) }
     }
@@ -71,7 +71,7 @@ impl<'a, 'b, T> Sub<&'b Vector<T>> for &'a mut Vector<T>
     /// &mut a - &b;
     /// assert_eq!(res_ref, a)
     /// ```
-    fn sub(self: Self, rhs: &'b Vector<T>) -> Self::Output
+    fn sub(self, rhs: &'b Vector<T>) -> Self::Output
     {
         let _ = &mut self.data - &rhs.data;
         self
@@ -95,7 +95,7 @@ impl<T> Sub<T> for Vector<T>
     ///
     /// assert_eq!(res_ref, a - -5.0)
     /// ```
-    fn sub(mut self: Self, rhs: T) -> Self::Output
+    fn sub(mut self, rhs: T) -> Self::Output
     {
         self.data = (&self.data).sub(&rhs);
         self
@@ -119,7 +119,7 @@ impl<'a, T> Sub<&T> for &'a Vector<T>
     ///
     /// assert_eq!(res_ref, a - 5.0)
     /// ```
-    fn sub(self: Self, rhs: &T) -> Self::Output
+    fn sub(self, rhs: &T) -> Self::Output
     {
         Vector { data: (&self.data).sub(rhs) }
     }
@@ -142,7 +142,7 @@ impl<'a, T> Sub<&T> for &'a mut Vector<T>
     ///
     /// assert_eq!(res_ref, *(&mut a - &5.0))
     /// ```
-    fn sub(self: Self, rhs: &T) -> Self::Output
+    fn sub(self, rhs: &T) -> Self::Output
     {
         let _ = &mut self.data - rhs;
         self
