@@ -12,10 +12,6 @@ use serde::{Deserialize, Serialize};
 
 /// Solves an ODE using the 4th order Runge-Kutta-Fehlberg algorithm.
 ///
-/// ```math
-/// order \mathcal{O}(h^4) with an error estimator of order \mathcal{O}(h^5)
-/// ```
-///
 ///<https://en.wikipedia.org/wiki/Runge-Kutta-Fehlberg_method>
 ///
 /// # Example
@@ -25,18 +21,18 @@ use serde::{Deserialize, Serialize};
 /// ```math
 /// \frac{dy}{dt} = ay = f(t, y)
 /// ```
-/// The initial condition is $`y(0) = 0.5`$ and we solve it in the interval
-/// $`\lbrack 0, 2\rbrack`$ The following equation is the closed solution for
+/// The initial condition is $y(0) = 0.5$ and we solve it in the interval
+/// $\lbrack 0, 2\rbrack$ The following equation is the closed solution for
 /// this ODE:
 /// ```math
 /// y(t) = C a e^{at}
 /// ```
-/// $`C`$ is a parameter and depends on the initial condition $`y(t_{0})`$
+/// $C$ is a parameter and depends on the initial condition $y(t_{0})$
 /// ```math
 /// C = \frac{y(t_{0})}{ae^{at_{0}}}
 /// ```
 ///
-/// In this example, we set $`a=2`$
+/// In this example, we set $a=2$
 /// ```
 /// # #[macro_use]
 /// # extern crate mathru;
@@ -64,17 +60,17 @@ use serde::{Deserialize, Serialize};
 ///
 /// impl ExplicitODE<f64> for ExplicitODE1
 /// {
-///     fn func(self: &Self, _t: &f64, x: &Vector<f64>) -> Vector<f64>
+///     fn func(&self, _t: &f64, x: &Vector<f64>) -> Vector<f64>
 ///     {
 ///         return x * &2.0f64;
 ///     }
 ///
-///     fn time_span(self: &Self) -> (f64, f64)
+///     fn time_span(&self) -> (f64, f64)
 ///     {
 ///         return self.time_span;
 ///     }
 ///
-///     fn init_cond(self: &Self) -> Vector<f64>
+///     fn init_cond(&self) -> Vector<f64>
 ///     {
 ///         return self.init_cond.clone();
 ///     }
@@ -124,7 +120,7 @@ impl<T> Default for Fehlberg45<T> where T: Real
 
 impl<T> ExplicitEmbeddedMethod<T> for Fehlberg45<T> where T: Real
 {
-    fn do_step<F>(self: &Self,
+    fn do_step<F>(&self,
                   prob: &F,
                   t_n: &T,
                   x_n: &Vector<T>,
@@ -135,7 +131,7 @@ impl<T> ExplicitEmbeddedMethod<T> for Fehlberg45<T> where T: Real
         self.butcher.do_step(prob, t_n, x_n, h_n)
     }
 
-    fn order(self: &Self) -> (u8, u8)
+    fn order(&self) -> (u8, u8)
     {
         (5, 4)
     }
