@@ -9,16 +9,16 @@ use crate::algebra::{
 pub trait ImplicitODE<T>
     where T: Real
 {
-    fn func(self: &Self, t: &T, x: &Vector<T>) -> Vector<T>;
+    fn func(&self, t: &T, x: &Vector<T>) -> Vector<T>;
 
-    fn jacobian(self: &Self, t: &T, x: &Vector<T>) -> Matrix<T>;
+    fn jacobian(&self, t: &T, x: &Vector<T>) -> Matrix<T>;
 
-    fn time_span(self: &Self) -> (T, T)
+    fn time_span(&self) -> (T, T)
     {
         unimplemented!();
     }
 
-    fn init_cond(self: &Self) -> Vector<T>
+    fn init_cond(&self) -> Vector<T>
     {
         unimplemented!();
     }
