@@ -39,14 +39,14 @@ impl<T> Default for Ralston4<T> where T: Real
 
 impl<T> ExplicitMethod<T> for Ralston4<T> where T: Real
 {
-    fn do_step<F>(self: &Self, prob: &F, t_n: &T, x_n: &Vector<T>, h: &T) -> Vector<T>
+    fn do_step<F>(&self, prob: &F, t_n: &T, x_n: &Vector<T>, h: &T) -> Vector<T>
         where F: ExplicitODE<T>
     {
         self.butcher.do_step(prob, t_n, x_n, h)
     }
 
     // Ralston's method is a 4th order method
-    fn order(self: &Self) -> u8
+    fn order(&self) -> u8
     {
         4
     }
