@@ -69,7 +69,7 @@ impl<T> Discrete<T, u32, u32> for Poisson<T>
     /// let x: u32 = 5;
     /// let p: f64 = distrib.pmf(x);
     /// ```
-    fn pmf(self: &Self, x: u32) -> T
+    fn pmf(&self, x: u32) -> T
     {
         let k_fact: T = T::from_u64(combins::factorial(x));
         self.gamma.pow(T::from_u32(x)) * (-self.gamma).exp() / k_fact
@@ -90,7 +90,7 @@ impl<T> Discrete<T, u32, u32> for Poisson<T>
     /// let x: u32 = 4;
     /// let p: f64 = distrib.cdf(x);
     /// ```
-    fn cdf(self: &Self, x: u32) -> T
+    fn cdf(&self, x: u32) -> T
     {
         special::gamma::gamma_ur(T::from_u32(x + 1), self.gamma)
     }
@@ -105,7 +105,7 @@ impl<T> Discrete<T, u32, u32> for Poisson<T>
     /// let distrib: Poisson<f64> = Poisson::new(&0.2);
     /// let mean: f64 = distrib.mean();
     /// ```
-    fn mean(self: &Self) -> T
+    fn mean(&self) -> T
     {
         self.gamma
     }
@@ -120,7 +120,7 @@ impl<T> Discrete<T, u32, u32> for Poisson<T>
     /// let distrib: Poisson<f64> = Poisson::new(&0.2);
     /// let var: f64 = distrib.variance();
     /// ```
-    fn variance(self: &Self) -> T
+    fn variance(&self) -> T
     {
         self.gamma
     }
